pub fn get_marked(_: ()) -> Option<Dictionary>Expand description
Extract the last Visual selection using persisted '< / '> marks.
This is meant for integrations that leave Visual mode before acting on the selected text.
pub fn get_marked(_: ()) -> Option<Dictionary>Extract the last Visual selection using persisted '< / '> marks.
This is meant for integrations that leave Visual mode before acting on the selected text.