pub struct SelectionBounds {
buf_id: i32,
start: Bound,
end: Bound,
}Expand description
Start / end bounds plus owning buffer id for a Visual selection.
Fields
buf_id: i32start: Boundend: BoundImplementations
Sourceimpl SelectionBounds
impl SelectionBounds
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Builds selection bounds from the current cursor (.) and visual start (v) marks.
Retrieves positions using Nvim’s getpos() function and normalizes them to 0-based indices.
The start and end are sorted to ensure start is before end.
Errors
- Fails if retrieving either mark fails.
- Fails if the two marks reference different buffers.
Sourcepub const fn line_range(&self) -> Range<usize>
pub const fn line_range(&self) -> Range<usize>
Range of starting (inclusive) to ending (exclusive) line indices.
Sourcepub const fn end(&self) -> &Bound
pub const fn end(&self) -> &Bound
End bound (exclusive line, exclusive column for charwise mode after adjustment).
Sourceconst fn incr_end_col(&mut self)
const fn incr_end_col(&mut self)
Increment end column (making it exclusive for charwise selections).